@@ -1,6 +1,6 @@
 /* mpfr_root -- kth root.
 
-Copyright 2005-2016 Free Software Foundation, Inc.
+Copyright 2005-2019 Free Software Foundation, Inc.
 Contributed by the AriC and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
@@ -17,7 +17,7 @@ License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
-http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
+https://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 #define MPFR_NEED_LONGLONG_H
@@ -45,7 +45,7 @@ mpfr_root_aux (mpfr_ptr y, mpfr_srcptr x, unsigned long k,
                mpfr_rnd_t rnd_mode);
 
 int
-mpfr_root (mpfr_ptr y, mpfr_srcptr x, unsigned long k, mpfr_rnd_t rnd_mode)
+mpfr_rootn_ui (mpfr_ptr y, mpfr_srcptr x, unsigned long k, mpfr_rnd_t rnd_mode)
 {
   mpz_t m;
   mpfr_exp_t e, r, sh, f;
@@ -63,6 +63,7 @@ mpfr_root (mpfr_ptr y, mpfr_srcptr x, unsigned long k, mpfr_rnd_t rnd_mode)
     {
       if (k == 0)
         {
+          /* rootn(x,0) is NaN (IEEE 754-2008). */
           MPFR_SET_NAN (y);
           MPFR_RET_NAN;
         }
@@ -79,34 +80,43 @@ mpfr_root (mpfr_ptr y, mpfr_srcptr x, unsigned long k, mpfr_rnd_t rnd_mode)
           MPFR_RET_NAN;
         }
 
-      if (MPFR_IS_INF (x)) /* +Inf^(1/k) = +Inf
-                              -Inf^(1/k) = -Inf if k odd
-                              -Inf^(1/k) = NaN if k even */
+      if (MPFR_IS_INF (x)) /* (+Inf)^(1/k) = +Inf
+                              (-Inf)^(1/k) = -Inf if k odd
+                              (-Inf)^(1/k) = NaN if k even */
         {
-          if (MPFR_IS_NEG(x) && (k % 2 == 0))
+          if (MPFR_IS_NEG (x) && (k & 1) == 0)
             {
               MPFR_SET_NAN (y);
               MPFR_RET_NAN;
             }
           MPFR_SET_INF (y);
+          MPFR_SET_SAME_SIGN (y, x);
         }
       else /* x is necessarily 0: (+0)^(1/k) = +0
                                   (-0)^(1/k) = -0 */
         {
           MPFR_ASSERTD (MPFR_IS_ZERO (x));
           MPFR_SET_ZERO (y);
+          if (MPFR_IS_POS (x) || (k & 1) == 0)
+            MPFR_SET_POS (y);
+          else
+            MPFR_SET_NEG (y);
         }
-      MPFR_SET_SAME_SIGN (y, x);
       MPFR_RET (0);
     }
 
   /* Returns NAN for x < 0 and k even */
-  if (MPFR_UNLIKELY (MPFR_IS_NEG (x) && (k % 2 == 0)))
+  if (MPFR_UNLIKELY (MPFR_IS_NEG (x) && (k & 1) == 0))
     {
       MPFR_SET_NAN (y);
       MPFR_RET_NAN;
     }
 
+  /* Special case |x| = 1. Note that if x = -1, then k is odd
+     (NaN results have already been filtered), so that y = -1. */
+  if (mpfr_cmpabs (x, __gmpfr_one) == 0)
+    return mpfr_set (y, x, rnd_mode);
+
   /* General case */
 
   /* For large k, use exp(log(x)/k). The threshold of 100 seems to be quite
@@ -188,6 +198,14 @@ mpfr_root (mpfr_ptr y, mpfr_srcptr x, unsigned long k, mpfr_rnd_t rnd_mode)
    Assume all special cases have been eliminated before.
    In the extended exponent range, overflows/underflows are not possible.
    Assume x > 0, or x < 0 and k odd.
+   Also assume |x| <> 1 because log(1) = 0, which does not have an exponent
+   and would yield a failure in the error bound computation. A priori, this
+   constraint is quite artificial because if |x| is close enough to 1, then
+   the exponent of log|x| does not need to be used (in the code, err would
+   be 1 in such a domain). So this constraint |x| <> 1 could be avoided in
+   the code. However, this is an exact case easy to detect, so that such a
+   change would be useless. Values very close to 1 are not an issue, since
+   an underflow is not possible before the MPFR_GET_EXP.
 */
 static int
 mpfr_root_aux (mpfr_ptr y, mpfr_srcptr x, unsigned long k, mpfr_rnd_t rnd_mode)
@@ -219,7 +237,8 @@ mpfr_root_aux (mpfr_ptr y, mpfr_srcptr x, unsigned long k, mpfr_rnd_t rnd_mode)
       mpfr_log (t, absx, MPFR_RNDN);
       /* t = log|x| * (1 + theta) with |theta| <= 2^(-w) */
       mpfr_div_ui (t, t, k, MPFR_RNDN);
-      expt = MPFR_GET_EXP (t);
+      /* No possible underflow in mpfr_log and mpfr_div_ui. */
+      expt = MPFR_GET_EXP (t);  /* assumes t <> 0 */
       /* t = log|x|/k * (1 + theta) + eps with |theta| <= 2^(-w)
          and |eps| <= 1/2 ulp(t), thus the total error is bounded
          by 1.5 * 2^(expt - w) */
@@ -277,3 +296,36 @@ mpfr_root_aux (mpfr_ptr y, mpfr_srcptr x, unsigned long k, mpfr_rnd_t rnd_mode)
 
   return mpfr_check_range (y, inexact, rnd_mode);
 }
+
+int
+mpfr_root (mpfr_ptr y, mpfr_srcptr x, unsigned long k, mpfr_rnd_t rnd_mode)
+{
+  MPFR_LOG_FUNC
+    (("x[%Pu]=%.*Rg k=%lu rnd=%d",
+      mpfr_get_prec (x), mpfr_log_prec, x, k, rnd_mode),
+     ("y[%Pu]=%.*Rg",
+      mpfr_get_prec (y), mpfr_log_prec, y));
+
+  /* Like mpfr_rootn_ui... */
+  if (MPFR_UNLIKELY (k <= 1))
+    {
+      if (k == 0)
+        {
+          /* rootn(x,0) is NaN (IEEE 754-2008). */
+          MPFR_SET_NAN (y);
+          MPFR_RET_NAN;
+        }
+      else /* y = x^(1/1) = x */
+        return mpfr_set (y, x, rnd_mode);
+    }
+
+  if (MPFR_UNLIKELY (MPFR_IS_ZERO (x)))
+    {
+      /* The only case that may differ from mpfr_rootn_ui. */
+      MPFR_SET_ZERO (y);
+      MPFR_SET_SAME_SIGN (y, x);
+      MPFR_RET (0);
+    }
+  else
+    return mpfr_rootn_ui (y, x, k, rnd_mode);
+}
