@@ -1,7 +1,7 @@
 /* Test file for mpfr_get_d
 
-Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012 Free Software Foundation, Inc.
-Contributed by the AriC and Caramel projects, INRIA.
+Copyright 1999-2019 Free Software Foundation, Inc.
+Contributed by the AriC and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
@@ -17,11 +17,9 @@ License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
-http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
+https://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
-#include <stdio.h>
-#include <stdlib.h>
 #include <float.h>
 
 #include "mpfr-test.h"
@@ -91,7 +89,7 @@ static void
 check_inf_nan (void)
 {
   /* only if nans and infs are available */
-#if _GMP_IEEE_FLOATS && !defined(MPFR_ERRDIVZERO)
+#if !defined(MPFR_ERRDIVZERO)
   mpfr_t  x;
   double  d;
 
@@ -99,17 +97,17 @@ check_inf_nan (void)
 
   mpfr_set_inf (x, 1);
   d = mpfr_get_d (x, MPFR_RNDZ);
-  ASSERT_ALWAYS (d > 0);
-  ASSERT_ALWAYS (DOUBLE_ISINF (d));
+  MPFR_ASSERTN (d > 0);
+  MPFR_ASSERTN (DOUBLE_ISINF (d));
 
   mpfr_set_inf (x, -1);
   d = mpfr_get_d (x, MPFR_RNDZ);
-  ASSERT_ALWAYS (d < 0);
-  ASSERT_ALWAYS (DOUBLE_ISINF (d));
+  MPFR_ASSERTN (d < 0);
+  MPFR_ASSERTN (DOUBLE_ISINF (d));
 
   mpfr_set_nan (x);
   d = mpfr_get_d (x, MPFR_RNDZ);
-  ASSERT_ALWAYS (DOUBLE_ISNAN (d));
+  MPFR_ASSERTN (DOUBLE_ISNAN (d));
 
   mpfr_clear (x);
 #endif
@@ -141,7 +139,7 @@ check_max (void)
   MPFR_ASSERTN(d == -DBL_MAX);
   d = mpfr_get_d (u, MPFR_RNDU);
   MPFR_ASSERTN(d == -DBL_MAX);
-#if _GMP_IEEE_FLOATS && !defined(MPFR_ERRDIVZERO)
+#if !defined(MPFR_ERRDIVZERO)
   d = mpfr_get_d (u, MPFR_RNDN);
   MPFR_ASSERTN(DOUBLE_ISINF(d) && d < 0.0);
   d = mpfr_get_d (u, MPFR_RNDD);
@@ -153,7 +151,7 @@ check_max (void)
   MPFR_ASSERTN(d == DBL_MAX);
   d = mpfr_get_d (u, MPFR_RNDD);
   MPFR_ASSERTN(d == DBL_MAX);
-#if _GMP_IEEE_FLOATS && !defined(MPFR_ERRDIVZERO)
+#if !defined(MPFR_ERRDIVZERO)
   d = mpfr_get_d (u, MPFR_RNDN);
   MPFR_ASSERTN(DOUBLE_ISINF(d) && d > 0.0);
   d = mpfr_get_d (u, MPFR_RNDU);
@@ -187,12 +185,12 @@ check_min(void)
 static void
 check_get_d_2exp_inf_nan (void)
 {
+#if !defined(MPFR_ERRDIVZERO)
+
   double var_d;
   long exp;
   mpfr_t var;
 
-#if !defined(MPFR_ERRDIVZERO)
-
   mpfr_init2 (var, MPFR_PREC_MIN);
 
   mpfr_set_nan (var);
